@@ -1,6 +1,7 @@
 from django.contrib import admin
 
-from models import AttributeSource, UserAliasInSource
+from .models import (AttributeSource, UserAliasInSource,
+        AttributeItem, AttributeList)
 
 class LdapSourceAdmin(admin.ModelAdmin):
     fieldsets = (
@@ -19,11 +20,25 @@ class LdapSourceAdmin(admin.ModelAdmin):
             }),
     )
 
+class AttributeListAdmin(admin.ModelAdmin):
+    filter_horizontal = ('attributes', )
+    fieldsets = (
+            (None, {
+                'fields' : (
+                    'name',
+                    'attributes',
+                )
+            }),
+    )
+
+
 admin.site.register(AttributeSource)
 admin.site.register(UserAliasInSource)
+admin.site.register(AttributeItem)
+admin.site.register(AttributeList, AttributeListAdmin)
 
 try:
-    from models import LdapSource
+    from .models import LdapSource
     admin.site.register(LdapSource, LdapSourceAdmin)
 except ImportError:
     pass
