@@ -1,7 +1,7 @@
 '''
-    VERIDIC Project - Towards a centralized access control system
+    Authentic 2 - Versatile Identity Server
 
-    Copyright (C) 2011  Mikael Ates
+    Copyright (C) 2011 Entr'ouvert
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Affero General Public License as
@@ -27,11 +27,23 @@ from django.db import transaction
 from django.core.exceptions import ObjectDoesNotExist
 
 from authentic2.attribute_aggregator.xacml_constants import *
-from authentic2.attribute_aggregator.mapping import ATTRIBUTE_MAPPING
+from authentic2.attribute_aggregator.mapping_loader import ATTRIBUTE_MAPPING
 
 
 logger = logging.getLogger('attribute_aggregator')
 
+class INDEXES(object):
+
+    @classmethod
+    def setup_idxs(cls):
+        cls.by_profile_field_name = {}
+        for key, mapping in ATTRIBUTE_MAPPING.iteritems():
+            if mapping.get('profile_field_name'):
+                l = cls.by_profile_field_name.setdefault(mapping['profile_field_name'],
+                        [])
+                l.append(key)
+
+INDEXES.setup_idxs()
 
 def iso8601_to_datetime(date_string):
     '''
@@ -114,14 +126,11 @@ def get_profile_field_name_from_definition(definition):
     return None
 
 
-def get_definition_from_profile_field_name(field_name):
+def get_definitions_from_profile_field_name(field_name):
     if not field_name:
-        return None
-    for def_name, content in ATTRIBUTE_MAPPING.items():
-        if 'profile_field_name' in content:
-            if field_name == content['profile_field_name']:
-                return def_name
-    return None
+        return ()
+    keys = INDEXES.by_profile_field_name.get(field_name, ())
+    return [ATTRIBUTE_MAPPING[key] for key in keys]
 
 
 def get_def_name_from_name_and_ns_of_attribute(name, namespace):
@@ -345,3 +354,13 @@ def set_user_alias_in_source(user, source, name, force_change=False):
         logger.error('set_user_alias_in_source: unable to create alias due \
             to %s.' % str(err))
         return None
+
+def is_definition(definition):
+    '''Return whether a definition is known'''
+    return definition in ATTRIBUTE_MAPPING
+
+def get_aliases(definition):
+    if definition in ATTRIBUTE_MAPPING:
+        if 'alias' in ATTRIBUTE_MAPPING[definition]:
+            return [definition] + ATTRIBUTE_MAPPING[definition]['alias']
+        return [definition]
