@@ -1,13 +1,10 @@
-import logging
 import urllib
+import re
 
-from django.contrib.auth.forms import AuthenticationForm
 from django.contrib.auth.forms import PasswordChangeForm
-from django.contrib.auth import login as auth_login
 from django.contrib.auth import REDIRECT_FIELD_NAME
-from django import forms
 from django.http import HttpResponseRedirect
-from django.views.decorators.csrf import csrf_exempt, csrf_protect
+from django.views.decorators.csrf import csrf_protect
 from django.contrib.auth.decorators import login_required
 from django.utils.http import urlencode
 from django.contrib.sites.models import Site, RequestSite
@@ -17,31 +14,12 @@ from django.core.urlresolvers import reverse
 from django.shortcuts import render_to_response
 from django.template import RequestContext
 from django.template.loader import render_to_string
+from django.views.generic.base import TemplateView
 
-from authentic2.saml.common import *
 from authentic2.auth2_auth import NONCE_FIELD_NAME
 from authentic2.idp import get_backends
-import models
 
-class WithNonceAuthenticationForm(AuthenticationForm):
-    nonce = forms.CharField(label='Nonce', widget=forms.HiddenInput,
-            required = False)
-
-    def __init__(self, request = None, **kwargs):
-        AuthenticationForm.__init__(self, request, **kwargs)
-        if request and NONCE_FIELD_NAME in request.REQUEST:
-            self.initial[NONCE_FIELD_NAME] = request.REQUEST.get(NONCE_FIELD_NAME)
-
-    def clean(self):
-        res = AuthenticationForm.clean(self)
-        # create an authentication event
-        if self.user_cache and NONCE_FIELD_NAME in self.cleaned_data:
-            how = 'password'
-            if self.request and 'HTTPS' in self.request.environ:
-                how = 'password-on-https'
-            models.AuthenticationEvent(who=self.user_cache.username,
-                    how=how, nonce=self.cleaned_data[NONCE_FIELD_NAME]).save()
-        return res
+from .. import app_settings
 
 def add_arg(url, key, value = None):
     '''Add a parameter to an URL'''
@@ -59,8 +37,7 @@ def add_arg(url, key, value = None):
 @never_cache
 def login(request, template_name='auth/login.html',
           login_form_template='auth/login_form.html',
-          redirect_field_name=REDIRECT_FIELD_NAME,
-          authentication_form=WithNonceAuthenticationForm):
+          redirect_field_name=REDIRECT_FIELD_NAME):
     """Displays the login form and handles the login action."""
 
     redirect_to = request.REQUEST.get(redirect_field_name)
@@ -109,6 +86,8 @@ def login(request, template_name='auth/login.html',
         context = { 'cancel': nonce is not None,
                     'submit_name': 'submit-%s' % d['backend'].id(),
                     redirect_field_name: redirect_to,
+                    'can_reset_password': app_settings.A2_CAN_RESET_PASSWORD,
+                    'registration_authorized': app_settings.A2_REGISTRATION_AUTHORIZED,
                     'form': d['form'] }
         if hasattr(d['backend'], 'get_context'):
             context.update(d['backend'].get_context())
@@ -171,3 +150,8 @@ def redirect_to_login(request, next=None, nonce=None, keep_qs=False):
     if nonce is not None:
         qs.update({ NONCE_FIELD_NAME: nonce })
     return HttpResponseRedirect('/login?%s' % urlencode(qs))
+
+class SslErrorView(TemplateView):
+    template_name = 'error_ssl.html'
+
+error_ssl = SslErrorView.as_view()
