@@ -1,11 +1,11 @@
 import urlparse
 import os.path
 import urllib
+import urllib2
 import httplib
 import logging
 import re
 import datetime
-import time
 
 import lasso
 from django.template import RequestContext
@@ -17,7 +17,7 @@ from django.db import transaction
 from django.core.exceptions import ValidationError
 from django.core.exceptions import ObjectDoesNotExist
 
-from authentic2.saml.models import LibertyFederation, LibertyIdentityDump, LibertyProvider, \
+from authentic2.saml.models import LibertyFederation, LibertyProvider, \
     LibertyManageDump, LibertySessionDump, LibertyServiceProvider, \
     LibertyIdentityProvider, LibertySessionSP, IdPOptionsSPPolicy, \
     SPOptionsIdPPolicy, \
@@ -25,7 +25,6 @@ from authentic2.saml.models import LibertyFederation, LibertyIdentityDump, Liber
     LIBERTY_SESSION_DUMP_KIND_IDP
 from authentic2.saml import models
 from authentic2.saml import saml2utils
-from authentic2.saml import saml11utils
 
 from authentic2.authsaml2 import signals
 from authentic2.http_utils import get_url
@@ -60,7 +59,7 @@ def get_soap_message(request, on_error_raise = True):
     if request.method != 'POST' or \
             'text/xml' not in request.META['CONTENT_TYPE']:
        if on_error_raise:
-           raise Http404(_('Only SOAP messages here'))
+           raise Http404('Only SOAP messages here')
        else:
            return None
     return request.raw_post_data
@@ -186,7 +185,7 @@ def check_id_and_issue_instant(request_response_or_assertion, now=None):
         now = datetime.datetime.utcnow()
     try:
         issue_instant = request_response_or_assertion.issueInstant
-        issue_instant = iso8601_to_datetime(issue_instant)
+        issue_instant = saml2utils.iso8601_to_datetime(issue_instant)
         delta = datetime.timedelta(seconds=NONCE_TIMEOUT)
         if not (now - delta <= issue_instant < now + delta):
             logger.warning('IssueInstant %s not in the interval [%s, %s[',
@@ -206,78 +205,51 @@ def check_id_and_issue_instant(request_response_or_assertion, now=None):
             return False
     return True
 
-# ID-FF 1.2 methods
-def get_idff12_metadata(request, metadata):
-    '''Produce SAMLv1.1 metadata for our ID-FF 1.2 IdP
-
-      This method only works with request pointing to an endpoint'''
-
-    metagen = saml11utils.Saml11Metadata(get_entity_id(request, metadata),
-            url_prefix = get_base_path(request, metadata),
-            protocol_support_enumeration = [ lasso.LIB_HREF ])
-    sso_protocol_profiles = [
-        lasso.LIB_PROTOCOL_PROFILE_BRWS_ART,
-        lasso.LIB_PROTOCOL_PROFILE_BRWS_POST,
-        lasso.LIB_PROTOCOL_PROFILE_BRWS_LECP ]
-    map = {
-            'SoapEndpoint': '/soap',
-            'SingleSignOn': (('/sso',), sso_protocol_profiles)
-          }
-    options = { 'key': settings.SAML_SIGNATURE_PUBLIC_KEY }
-    metagen.add_idp_descriptor(map, options)
-    return str(metagen)
-
-def create_idff12_server(request, metadata):
-    server = lasso.Server.newFromBuffers(get_idff12_metadata(request,
-        metadata), settings.SAML_SIGNATURE_PRIVATE_KEY)
-    if not server:
-        raise Exception('Cannot create LassoServer object')
-    return server
-
-def get_idff12_post_request(request):
-    '''Return a SAML 1.1 request transmitted through a POST request'''
-    return request.POST.get('LAREQ')
-
-get_idff12_query_request = get_saml2_query_request
-
-def get_idff12_request_message(request):
-    binding = get_http_binding(request)
-    if binding == 'GET':
-        return get_idff12_query_request(request)
-    elif binding == 'POST':
-        return get_idff12_post_request(request)
-
 def return_saml_soap_response(profile):
     return HttpResponse(profile.msgBody, mimetype = 'text/xml')
 
-def return_idff12_response(request, profile, title = ''):
-    '''Finish your ID-FFv1.2 views with this method to return a SAML
-    response'''
-    return return_saml2(request, profile, 'LARES', title)
-
-def return_idff12_request(request, profile, title = ''):
-    '''Finish your SAMLv2 views with this method to return a SAML
-    request'''
-    return return_saml2(request, profile, 'LAREQ', title)
-
 # Helper method to handle profiles endpoints
 # In the future we should move away from monolithic object (LassoIdentity and
 # LassoSession) holding all the datas, to manipulate them at row Level with
 # LibertyFederation and LibertyAssertion objects.
 
-def load_federation(request, login, user = None):
+START_IDENTITY_DUMP = '''<Identity xmlns="http://www.entrouvert.org/namespaces/lasso/0.0" Version="2">
+'''
+MIDDLE_IDENTITY_DUMP = '''<lasso:Federation xmlns:lasso="http://www.entrouvert.org/namespaces/lasso/0.0" xmlns:saml="urn:oasis:names:tc:SAML:2.0:assertion" RemoteProviderID="{sp_id}" FederationDumpVersion="2">
+    <lasso:LocalNameIdentifier>
+        <saml:NameID Format="{format}" NameQualifier="{idp_id}" SPNameQualifier="{sp_id}">{content}</saml:NameID>
+    </lasso:LocalNameIdentifier>
+</lasso:Federation>
+'''
+END_IDENTITY_DUMP = '''</Identity>'''
+
+
+def federations_to_identity_dump(self_entity_id, federations):
+    l = [ START_IDENTITY_DUMP ]
+    for federation in federations:
+        if federation.sp:
+            sp_id = federation.sp.liberty_provider.entity_id
+            idp_id = self_entity_id
+        elif federation.idp:
+            idp_id = federation.idp.liberty_provider.entity_id
+            sp_id = self_entity_id
+        l.append(MIDDLE_IDENTITY_DUMP.format(
+            content=federation.name_id_content,
+            format=federation.name_id_format,
+            sp_id=sp_id,
+            idp_id=idp_id))
+    l.append(END_IDENTITY_DUMP)
+    return ''.join(l)
+
+def load_federation(request, entity_id, login, user = None):
     '''Load an identity dump from the database'''
     if not user:
         user = request.user
-    logger.debug('load_federation: user is %s' %user.username)
-    try:
-        q = LibertyIdentityDump.objects.get(user = user)
-        logger.debug('load_federation: identity dump found %s' %q.identity_dump.encode('utf8'))
-    except ObjectDoesNotExist:
-        pass
-    else:
-        login.setIdentityFromDump(q.identity_dump.encode('utf8'))
-        logger.debug('load_federation: set identity from dump done %s' %login.identity.dump())
+    assert user is not None
+
+    identity_dump = federations_to_identity_dump(entity_id,
+            LibertyFederation.objects.filter(user=user))
+    login.setIdentityFromDump(identity_dump)
 
 def load_session(request, login, session_key = None,
         kind=LIBERTY_SESSION_DUMP_KIND_IDP):
@@ -293,18 +265,6 @@ def load_session(request, login, session_key = None,
     except ObjectDoesNotExist:
         pass
 
-def save_federation(request, login, user = None):
-    '''Save identity dump to database'''
-    if not user:
-        user = request.user
-    if login.isIdentityDirty:
-        q, creation = LibertyIdentityDump.objects.get_or_create(user = user)
-        if login.identity:
-            q.identity_dump = login.identity.dump()
-        else:
-            q.identity_dump = None
-        q.save()
-
 def save_session(request, login, session_key=None,
         kind=LIBERTY_SESSION_DUMP_KIND_IDP):
     '''Save session dump to database'''
@@ -319,11 +279,13 @@ def save_session(request, login, session_key=None,
             q.session_dump = None
         q.save()
 
-def delete_session(request):
+def delete_session(request, session_key=None):
     '''Delete all liberty sessions for a django session'''
+    if not session_key:
+        session_key = request.session.session_key
     try:
         LibertySessionDump.objects.\
-            filter(django_session_key = request.session.session_key).delete()
+            filter(django_session_key = session_key).delete()
     except Exception, e:
         logger.error('delete_session: Exception %s' % str(e))
 
@@ -430,24 +392,13 @@ def load_provider(request, provider_id, server=None, sp_or_idp='sp',
 # Federation management
 def add_federation(user, login=None, name_id=None, provider_id=None):
     if not name_id:
-        if not login:
-            return None
-        if not login.nameIdentifier:
-            return None
-        if not login.nameIdentifier.content or not login.nameIdentifier.nameQualifier:
+        if not (login and login.nameIdentifier):
             return None
         name_id=login.nameIdentifier
-    qualifier = name_id.nameQualifier
-    if not qualifier and login:
-        qualifier = login.get_remoteProviderId()
-    fed = LibertyFederation()
-    fed.user = user
-    fed.name_id_content = name_id.content
-    fed.name_id_qualifier = qualifier
-    fed.name_id_sp_name_qualifier = name_id.sPNameQualifier
-    fed.name_id_format = name_id.format
+    kwargs = models.nameid2kwargs(name_id)
     if provider_id:
-        fed.idp_id = provider_id
+        kwargs['idp'] = LibertyProvider.objects.get(entity_id=provider_id).identity_provider
+    fed = LibertyFederation(user=user, **kwargs)
     fed.save()
     return fed
 
@@ -466,9 +417,9 @@ def lookup_federation_by_name_id_and_provider_id(name_id, provider_id):
     '''Try to find a LibertyFederation object for the given NameID and
        the provider id.'''
     kwargs = models.nameid2kwargs(name_id)
-    kwargs['idp_id'] = provider_id
+    kwargs['idp'] = LibertyProvider.objects.get(entity_id=provider_id).identity_provider
     try:
-        return LibertyFederation.objects.get(**kwargs)
+        return LibertyFederation.objects.get(user__isnull=False, **kwargs)
     except:
         return None
 
@@ -574,10 +525,12 @@ def get_session_index(request):
     except:
         return None
 
-def remove_liberty_session_sp(request):
+def remove_liberty_session_sp(request, session_key=None):
+    if not session_key:
+        session_key = request.session.session_key
     try:
         LibertySessionSP.objects.\
-            filter(django_session_key=request.session.session_key).delete()
+            filter(django_session_key=session_key).delete()
     except Exception, e:
         logger.error('remove_liberty_session_sp: Exception %s' % str(e))
 
@@ -586,7 +539,7 @@ def get_provider_of_active_session(request):
         return None
     try:
         s = LibertySessionSP.objects.get(django_session_key=request.session.session_key)
-        p = LibertyProvider.objects.get(entity_id=s.federation.name_id_qualifier)
+        p = s.federation.idp.liberty_provider
         return p
     except:
         return None
@@ -606,6 +559,11 @@ class SOAPException(Exception):
         self.url = url
 
 def soap_call(url, msg, client_cert = None):
+    if not client_cert:
+        request = urllib2.Request(url, data=msg,
+            headers={'Content-Type': 'text/xml'})
+        return urllib2.urlopen(request).read()
+
     if url.startswith('http://'):
         host, query = urllib.splithost(url[5:])
         conn = httplib.HTTPConnection(host)
@@ -652,14 +610,16 @@ def set_saml2_response_responder_status_code(response, code):
 
 __root_refererer_re = re.compile('^(https?://[^/]*/?)')
 
-def error_page(request, message, back = None, logger = None):
+def error_page(request, message, back = None, logger = None, warning=False):
     '''View that show a simple error page to the user with a back link.
 
          back - url for the back link, if None, return to root of the referer
                 or the local root.
     '''
-    if logger:
-        logger.error('Showing message %r on an error page' % message)
+    if not logger:
+        logger = logging
+    if warning:
+        logging.warning('Showing message %r on an error page' % message)
     else:
         logging.error('Showing message %r on an error page' % message)
     if back is None:
@@ -670,8 +630,10 @@ def error_page(request, message, back = None, logger = None):
                 back = root_referer.group(1)
         if back is None:
             back = '/'
-    return render_to_response('error.html', {'msg': message, 'back': back},
-            context_instance=RequestContext(request))
+    redirection_timeout = getattr(settings, 'REDIRECTION_TIMEOUT_AFTER_ERROR', 2000)
+    return render_to_response('error.html', {'msg': message, 'back': back,
+        'redir_timeout': redirection_timeout},
+        context_instance=RequestContext(request))
 
 def redirect_next(request, next):
     if next:
@@ -689,16 +651,6 @@ def soap_fault(request, faultcode='soap:Client', faultstring=None):
 </soap:Envelope>''' % locals()
     return HttpResponse(content, mimetype = "text/xml")
 
-def iso8601_to_datetime(date_string):
-    '''Convert a string formatted as an ISO8601 date into a time_t value.
-
-       This function ignores the sub-second resolution'''
-    m = re.match(r'(\d+-\d+-\d+T\d+:\d+:\d+)(?:\.\d+)?Z$', date_string)
-    if not m:
-        raise ValueError('Invalid ISO8601 date')
-    tm = time.strptime(m.group(1)+'Z', "%Y-%m-%dT%H:%M:%SZ")
-    return datetime.datetime.fromtimestamp(time.mktime(tm))
-
 def get_idp_options_policy(provider):
     try:
         return IdPOptionsSPPolicy.objects.get(name='All', enabled=True)
@@ -782,7 +734,7 @@ def get_session_not_on_or_after(assertion):
             if authn_statement.sessionNotOnOrAfter:
                 value = authn_statement.sessionNotOnOrAfter
                 try:
-                    session_not_on_or_afters.append(iso8601_to_datetime(value))
+                    session_not_on_or_afters.append(saml2utils.iso8601_to_datetime(value))
                 except ValueError:
                     logging.getLogger(__name__).error('unable to parse SessionNotOnOrAfter value %s, will use default value for session length.', value)
     if session_not_on_or_afters:
